==> vulkan4j-0.1.0-sources.jar: tech/icey/vk4j/datatype/VkStreamDescriptorSurfaceCreateInfoGGP.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkStreamDescriptorSurfaceCreateInfoGGP {
///     VkStructureType sType;
///     const void* pNext;
///     VkStreamDescriptorSurfaceCreateFlagsGGP flags;
///     GgpStreamDescriptor streamDescriptor;
/// } VkStreamDescriptorSurfaceCreateInfoGGP;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkStreamDescriptorSurfaceCreateInfoGGP.html">VkStreamDescriptorSurfaceCreateInfoGGP</a>
public record VkStreamDescriptorSurfaceCreateInfoGGP(MemorySegment segment) implements IPointer {
    public VkStreamDescriptorSurfaceCreateInfoGGP(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_STREAM_DESCRIPTOR_SURFACE_CREATE_INFO_GGP);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @enumtype(VkStreamDescriptorSurfaceCreateFlagsGGP.class) int flags() {
        return segment.get(LAYOUT$flags, OFFSET$flags);
    }

    public void flags(@enumtype(VkStreamDescriptorSurfaceCreateFlagsGGP.class) int value) {
        segment.set(LAYOUT$flags, OFFSET$flags, value);
    }

    public @unsigned int streamDescriptor() {
        return segment.get(LAYOUT$streamDescriptor, OFFSET$streamDescriptor);
    }

    public void streamDescriptor(@unsigned int value) {
        segment.set(LAYOUT$streamDescriptor, OFFSET$streamDescriptor, value);
    }

    public static VkStreamDescriptorSurfaceCreateInfoGGP allocate(Arena arena) {
        return new VkStreamDescriptorSurfaceCreateInfoGGP(arena.allocate(LAYOUT));
    }

    public static VkStreamDescriptorSurfaceCreateInfoGGP[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkStreamDescriptorSurfaceCreateInfoGGP[] ret = new VkStreamDescriptorSurfaceCreateInfoGGP[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkStreamDescriptorSurfaceCreateInfoGGP(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkStreamDescriptorSurfaceCreateInfoGGP clone(Arena arena, VkStreamDescriptorSurfaceCreateInfoGGP src) {
        VkStreamDescriptorSurfaceCreateInfoGGP ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkStreamDescriptorSurfaceCreateInfoGGP[] clone(Arena arena, VkStreamDescriptorSurfaceCreateInfoGGP[] src) {
        VkStreamDescriptorSurfaceCreateInfoGGP[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.JAVA_INT.withName("flags"),
        ValueLayout.JAVA_INT.withName("streamDescriptor")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$flags = PathElement.groupElement("flags");
    public static final PathElement PATH$streamDescriptor = PathElement.groupElement("streamDescriptor");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final OfInt LAYOUT$flags = (OfInt) LAYOUT.select(PATH$flags);
    public static final OfInt LAYOUT$streamDescriptor = (OfInt) LAYOUT.select(PATH$streamDescriptor);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$flags = LAYOUT.byteOffset(PATH$flags);
    public static final long OFFSET$streamDescriptor = LAYOUT.byteOffset(PATH$streamDescriptor);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$flags = LAYOUT$flags.byteSize();
    public static final long SIZE$streamDescriptor = LAYOUT$streamDescriptor.byteSize();
}

==> vulkan4j-0.2.2-sources.jar: tech/icey/vk4j/datatype/VkStreamDescriptorSurfaceCreateInfoGGP.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import org.jetbrains.annotations.Nullable;
import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkStreamDescriptorSurfaceCreateInfoGGP {
///     VkStructureType sType;
///     const void* pNext;
///     VkStreamDescriptorSurfaceCreateFlagsGGP flags;
///     GgpStreamDescriptor streamDescriptor;
/// } VkStreamDescriptorSurfaceCreateInfoGGP;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkStreamDescriptorSurfaceCreateInfoGGP.html">VkStreamDescriptorSurfaceCreateInfoGGP</a>
public record VkStreamDescriptorSurfaceCreateInfoGGP(MemorySegment segment) implements IPointer {
    public VkStreamDescriptorSurfaceCreateInfoGGP(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_STREAM_DESCRIPTOR_SURFACE_CREATE_INFO_GGP);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@Nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @enumtype(VkStreamDescriptorSurfaceCreateFlagsGGP.class) int flags() {
        return segment.get(LAYOUT$flags, OFFSET$flags);
    }

    public void flags(@enumtype(VkStreamDescriptorSurfaceCreateFlagsGGP.class) int value) {
        segment.set(LAYOUT$flags, OFFSET$flags, value);
    }

    public @unsigned int streamDescriptor() {
        return segment.get(LAYOUT$streamDescriptor, OFFSET$streamDescriptor);
    }

    public void streamDescriptor(@unsigned int value) {
        segment.set(LAYOUT$streamDescriptor, OFFSET$streamDescriptor, value);
    }

    public static VkStreamDescriptorSurfaceCreateInfoGGP allocate(Arena arena) {
        return new VkStreamDescriptorSurfaceCreateInfoGGP(arena.allocate(LAYOUT));
    }

    public static VkStreamDescriptorSurfaceCreateInfoGGP[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkStreamDescriptorSurfaceCreateInfoGGP[] ret = new VkStreamDescriptorSurfaceCreateInfoGGP[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkStreamDescriptorSurfaceCreateInfoGGP(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkStreamDescriptorSurfaceCreateInfoGGP clone(Arena arena, VkStreamDescriptorSurfaceCreateInfoGGP src) {
        VkStreamDescriptorSurfaceCreateInfoGGP ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkStreamDescriptorSurfaceCreateInfoGGP[] clone(Arena arena, VkStreamDescriptorSurfaceCreateInfoGGP[] src) {
        VkStreamDescriptorSurfaceCreateInfoGGP[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.JAVA_INT.withName("flags"),
        ValueLayout.JAVA_INT.withName("streamDescriptor")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$flags = PathElement.groupElement("flags");
    public static final PathElement PATH$streamDescriptor = PathElement.groupElement("streamDescriptor");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final OfInt LAYOUT$flags = (OfInt) LAYOUT.select(PATH$flags);
    public static final OfInt LAYOUT$streamDescriptor = (OfInt) LAYOUT.select(PATH$streamDescriptor);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$flags = LAYOUT.byteOffset(PATH$flags);
    public static final long OFFSET$streamDescriptor = LAYOUT.byteOffset(PATH$streamDescriptor);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$flags = LAYOUT$flags.byteSize();
    public static final long SIZE$streamDescriptor = LAYOUT$streamDescriptor.byteSize();
}
